@@ -14,7 +14,8 @@ import datetime
 import pkg_resources
 import sys, time
 
-KEYLEN = 32
+KEYLEN = 32 # per part
+FULLKEY = KEYLEN * 2
 DEFAULT_HOST = "v2.decipherinc.com"
 
 def date_to_isoformat(o):
@@ -55,7 +56,7 @@ class BeaconAPI(object):
         :return:
         """
         if not key.startswith('session '):
-            assert len(key) == KEYLEN, "API key specified is not exactly %d characters long" % KEYLEN
+            assert len(key) == FULLKEY, "API key specified is not exactly %d characters long" % FULLKEY
         self.key, self.host  = key, host
 
     @property
